Package: arcpullr
Type: Package
Title: Pull Data from an 'ArcGIS REST' API
Version: 0.3.5
Authors@R: c(person(given = "Paul",
           family = "Frater",
           role = c("aut", "cre"),
           email = "paul.frater@wisconsin.gov",
           comment = c(ORCID = "0000-0002-7237-6563")),
           person("Zac", "Driscoll",
           email = "zdriscoll@mmsd.com", 
           role = c("aut"),
           comment = c(ORCID = "0000-0002-8233-0980")))
License: GPL-3
Encoding: UTF-8
LazyData: true
Description: 
  Functions to efficiently query 'ArcGIS REST' APIs 
  <https://developers.arcgis.com/rest/>. 
  Both spatial and SQL queries can be used to retrieve data. 
  Simple Feature (sf) objects are utilized to perform spatial queries. 
  This package was neither produced nor is maintained by Esri.
Depends: R (>= 4.2.0), sf (>= 0.9.7),
Imports: httr (>= 1.4.1), jsonlite (>= 1.8.9), dplyr (>= 1.1.4),
        ggplot2 (>= 3.5.1), tidyr (>= 1.3.1), rlang (>= 1.1.4), raster
        (>= 3.6.30), terra (>= 1.8.15), purrr (>= 1.0.2), grDevices (>=
        4.3.3), graphics (>= 4.3.3), DT (>= 0.33), methods
RoxygenNote: 7.3.2
Suggests: testthat (>= 3.0.1), knitr (>= 1.30), rmarkdown (>= 2.6),
        rvest (>= 0.3.6), xml2 (>= 1.3.2), stringr (>= 1.4.0), cowplot
        (>= 1.1.1), magick (>= 2.5.2)
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-06-02 20:58:36 UTC; fratepnd
Author: Paul Frater [aut, cre] (ORCID: <https://orcid.org/0000-0002-7237-6563>),
  Zac Driscoll [aut] (ORCID: <https://orcid.org/0000-0002-8233-0980>)
Maintainer: Paul Frater <paul.frater@wisconsin.gov>
Repository: CRAN
Date/Publication: 2026-06-03 05:10:16 UTC
Built: R 4.6.0; ; 2026-06-03 08:08:51 UTC; unix
