# Generated by roxygen2: do not edit by hand

export(format_coords)
export(format_envelope_coords)
export(format_line_coords)
export(format_multipoint_coords)
export(format_point_coords)
export(format_polygon_coords)
export(get_geometry_type)
export(get_image_layer)
export(get_layer_by_envelope)
export(get_layer_by_line)
export(get_layer_by_multipoint)
export(get_layer_by_point)
export(get_layer_by_poly)
export(get_layer_by_spatial)
export(get_layer_info)
export(get_layer_legend)
export(get_map_layer)
export(get_service_type)
export(get_sf_crs)
export(get_spatial_layer)
export(get_table_layer)
export(match_legend_colors)
export(plot_layer)
export(plot_layer.sf)
export(raster_colors)
export(reykjanes_lava_flow_url)
export(sf_box)
export(sf_line)
export(sf_point)
export(sf_points)
export(sf_polygon)
export(sp_rel_xref)
export(sql_where)
export(valid_sp_rel)
export(wi_hydro_url)
export(wi_landcover_url)
export(wi_leaf_off_url)
exportMethods(plot_layer)
exportMethods(raster_colors)
import(purrr)
import(sf)
import(terra)
importFrom(DT,datatable)
importFrom(grDevices,col2rgb)
importFrom(methods,setMethod)
importFrom(rlang,.data)
importFrom(stats,setNames)
importFrom(utils,download.file)
